==> oce_0.12.orig.tar.gz: oce-OCE-0.12/src/StepData/StepData_FileProtocol.cxx <==
// Copyright (c) 1999-2012 OPEN CASCADE SAS
//
// The content of this file is subject to the Open CASCADE Technology Public
// License Version 6.5 (the "License"). You may not use the content of this file
// except in compliance with the License. Please obtain a copy of the License
// at http://www.opencascade.org and read it completely before using this file.
//
// The Initial Developer of the Original Code is Open CASCADE S.A.S., having its
// main offices at: 1, place des Freres Montgolfier, 78280 Guyancourt, France.
//
// The Original Code and all software distributed under the License is
// distributed on an "AS IS" basis, without warranty of any kind, and the
// Initial Developer hereby disclaims all such warranties, including without
// limitation, any warranties of merchantability, fitness for a particular
// purpose or non-infringement. Please see the License for the specific terms
// and conditions governing the rights and limitations under the License.

#include <StepData_FileProtocol.ixx>


//static TCollection_AsciiString  thename("");
static Standard_CString  thename = "";

//  Protocol fabrique a la demande avec d autres Protocoles


    StepData_FileProtocol::StepData_FileProtocol ()    {  }

    void StepData_FileProtocol::Add (const Handle(StepData_Protocol)& protocol)
{
  if (protocol.IsNull()) return;
  Handle(Standard_Type) ptype = protocol->DynamicType();
  Standard_Integer nb = thecomps.Length();
  for (Standard_Integer i = 1; i <= nb; i ++) {
    if (thecomps.Value(i)->IsInstance(ptype)) return;
  }
  thecomps.Append(protocol);
}


    Standard_Integer  StepData_FileProtocol::NbResources () const
      {  return thecomps.Length();  }

    Handle(Interface_Protocol) StepData_FileProtocol::Resource
  (const Standard_Integer num) const
      {  return Handle(Interface_Protocol)::DownCast(thecomps.Value(num));  }


    Standard_Integer  StepData_FileProtocol::TypeNumber
  (const Handle(Standard_Type)& atype) const
      {  return 0;  }


Standard_Boolean StepData_FileProtocol::GlobalCheck(const Interface_Graph& G,
                                                    Handle(Interface_Check)& ach) const
{
  Standard_Boolean res = Standard_False;
  Standard_Integer i,nb = NbResources();
  for (i = 1; i <= nb; i ++) res |= Resource(i)->GlobalCheck (G,ach);
  return res;
}


    Standard_CString StepData_FileProtocol::SchemaName () const
      {  return thename;  }

==> oce_0.15.orig.tar.gz: oce-OCE-0.15/src/StepData/StepData_FileProtocol.cxx <==
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and / or modify it
// under the terms of the GNU Lesser General Public version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <StepData_FileProtocol.ixx>


//static TCollection_AsciiString  thename("");
static Standard_CString  thename = "";

//  Protocol fabrique a la demande avec d autres Protocoles


    StepData_FileProtocol::StepData_FileProtocol ()    {  }

    void StepData_FileProtocol::Add (const Handle(StepData_Protocol)& protocol)
{
  if (protocol.IsNull()) return;
  Handle(Standard_Type) ptype = protocol->DynamicType();
  Standard_Integer nb = thecomps.Length();
  for (Standard_Integer i = 1; i <= nb; i ++) {
    if (thecomps.Value(i)->IsInstance(ptype)) return;
  }
  thecomps.Append(protocol);
}


    Standard_Integer  StepData_FileProtocol::NbResources () const
      {  return thecomps.Length();  }

    Handle(Interface_Protocol) StepData_FileProtocol::Resource
  (const Standard_Integer num) const
      {  return Handle(Interface_Protocol)::DownCast(thecomps.Value(num));  }


    Standard_Integer  StepData_FileProtocol::TypeNumber
  (const Handle(Standard_Type)& /*atype*/) const
      {  return 0;  }


Standard_Boolean StepData_FileProtocol::GlobalCheck(const Interface_Graph& G,
                                                    Handle(Interface_Check)& ach) const
{
  Standard_Boolean res = Standard_False;
  Standard_Integer i,nb = NbResources();
  for (i = 1; i <= nb; i ++) res |= Resource(i)->GlobalCheck (G,ach);
  return res;
}


    Standard_CString StepData_FileProtocol::SchemaName () const
      {  return thename;  }
